# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Faces.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Faces.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/vision/Faces.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\"G\n\x05\x46\x61\x63\x65s\x12\x1f\n\x05\x66\x61\x63\x65s\x18\x01 \x03(\x0b\x32\x10.rst.vision.Face\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\rB\x0b\x42\tFacesType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,])




_FACES = _descriptor.Descriptor(
  name='Faces',
  full_name='rst.vision.Faces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='faces', full_name='rst.vision.Faces.faces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.Faces.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.Faces.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=132,
)

_FACES.fields_by_name['faces'].message_type = rst_dot_vision_dot_Face__pb2._FACE
DESCRIPTOR.message_types_by_name['Faces'] = _FACES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Faces = _reflection.GeneratedProtocolMessageType('Faces', (_message.Message,), dict(
  DESCRIPTOR = _FACES,
  __module__ = 'rst.vision.Faces_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Faces)
  ))
_sym_db.RegisterMessage(Faces)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tFacesType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/DialogManagerCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/DialogManagerCommand.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n%rst/dialog/DialogManagerCommand.proto\x12\nrst.dialog\"\x9c\x01\n\x14\x44ialogManagerCommand\x12\x39\n\x07\x63ommand\x18\x01 \x02(\x0e\x32(.rst.dialog.DialogManagerCommand.Command\x12\x14\n\x0cpattern_name\x18\x02 \x01(\t\"3\n\x07\x43ommand\x12\x15\n\x11RESET_INTERACTION\x10\x00\x12\x11\n\rRESET_PATTERN\x10\x01\x42\x1a\x42\x18\x44ialogManagerCommandType')
)



_DIALOGMANAGERCOMMAND_COMMAND = _descriptor.EnumDescriptor(
  name='Command',
  full_name='rst.dialog.DialogManagerCommand.Command',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET_INTERACTION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_PATTERN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=159,
  serialized_end=210,
)
_sym_db.RegisterEnumDescriptor(_DIALOGMANAGERCOMMAND_COMMAND)


_DIALOGMANAGERCOMMAND = _descriptor.Descriptor(
  name='DialogManagerCommand',
  full_name='rst.dialog.DialogManagerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='rst.dialog.DialogManagerCommand.command', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pattern_name', full_name='rst.dialog.DialogManagerCommand.pattern_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIALOGMANAGERCOMMAND_COMMAND,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=210,
)

_DIALOGMANAGERCOMMAND.fields_by_name['command'].enum_type = _DIALOGMANAGERCOMMAND_COMMAND
_DIALOGMANAGERCOMMAND_COMMAND.containing_type = _DIALOGMANAGERCOMMAND
DESCRIPTOR.message_types_by_name['DialogManagerCommand'] = _DIALOGMANAGERCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DialogManagerCommand = _reflection.GeneratedProtocolMessageType('DialogManagerCommand', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGMANAGERCOMMAND,
  __module__ = 'rst.dialog.DialogManagerCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.DialogManagerCommand)
  ))
_sym_db.RegisterMessage(DialogManagerCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030DialogManagerCommandType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/SpeechHypothesis.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Interval_pb2 as rst_dot_timing_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/SpeechHypothesis.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n!rst/dialog/SpeechHypothesis.proto\x12\nrst.dialog\x1a\x19rst/timing/Interval.proto\"\xff\x06\n\x10SpeechHypothesis\x12\x30\n\x05words\x18\x01 \x03(\x0b\x32!.rst.dialog.SpeechHypothesis.Word\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\'\n\ttimestamp\x18\x03 \x01(\x0b\x32\x14.rst.timing.Interval\x12\x14\n\x0cgrammar_tree\x18\x04 \x01(\t\x1a\xe5\x05\n\x04Word\x12\x0c\n\x04word\x18\x01 \x02(\t\x12(\n\ntimestamps\x18\x02 \x01(\x0b\x32\x14.rst.timing.Interval\x12M\n\x12part_of_speech_tag\x18\x03 \x01(\x0e\x32\x31.rst.dialog.SpeechHypothesis.Word.PartOfSpeechTag\"\xd5\x04\n\x0fPartOfSpeechTag\x12\x08\n\x04\x41\x44JA\x10\x01\x12\x08\n\x04\x41\x44JD\x10\x02\x12\x07\n\x03\x41\x44V\x10\x03\x12\x08\n\x04\x41PPR\x10\x04\x12\x0b\n\x07\x41PPRART\x10\x05\x12\x08\n\x04\x41PPO\x10\x06\x12\x08\n\x04\x41PZR\x10\x07\x12\x07\n\x03\x41RT\x10\x08\x12\x08\n\x04\x43\x41RD\x10\t\x12\x06\n\x02\x46M\x10\n\x12\x07\n\x03ITJ\x10\x0b\x12\x07\n\x03ORD\x10\x0c\x12\x08\n\x04KOUI\x10\r\x12\x08\n\x04KOUS\x10\x0e\x12\x07\n\x03KON\x10\x0f\x12\t\n\x05KOKOM\x10\x10\x12\x06\n\x02NN\x10\x11\x12\x06\n\x02NE\x10\x12\x12\x07\n\x03PDS\x10\x13\x12\x08\n\x04PDAT\x10\x14\x12\x07\n\x03PIS\x10\x15\x12\x08\n\x04PIAT\x10\x16\x12\t\n\x05PIDAT\x10\x17\x12\x08\n\x04PPER\x10\x18\x12\t\n\x05PPOSS\x10\x19\x12\n\n\x06PPOSAT\x10\x1a\x12\t\n\x05PRELS\x10\x1b\x12\n\n\x06PRELAT\x10\x1c\x12\x07\n\x03PRF\x10\x1d\x12\x07\n\x03PWS\x10\x1e\x12\x08\n\x04PWAT\x10\x1f\x12\x08\n\x04PWAV\x10 \x12\x07\n\x03PAV\x10!\x12\t\n\x05PTKZU\x10\"\x12\n\n\x06PTKNEG\x10#\x12\t\n\x05PTKVZ\x10$\x12\n\n\x06PTKANT\x10%\x12\x08\n\x04PTKA\x10&\x12\x08\n\x04SGML\x10\'\x12\t\n\x05SPELL\x10(\x12\t\n\x05TRUNC\x10)\x12\t\n\x05VVFIN\x10*\x12\t\n\x05VVIMP\x10+\x12\t\n\x05VVINF\x10,\x12\t\n\x05VVIZU\x10-\x12\x08\n\x04VVPP\x10.\x12\t\n\x05VAFIN\x10/\x12\t\n\x05VAIMP\x10\x30\x12\t\n\x05VAINF\x10\x31\x12\x08\n\x04VAPP\x10\x32\x12\t\n\x05VMFIN\x10\x33\x12\t\n\x05VMINF\x10\x34\x12\x08\n\x04VMPP\x10\x35\x12\x06\n\x02XY\x10\x36\x12\x08\n\x04KOMM\x10\x37\x12\x07\n\x03\x45ND\x10\x38\x12\t\n\x05IPNCT\x10\x39\x42\x16\x42\x14SpeechHypothesisType')
  ,
  dependencies=[rst_dot_timing_dot_Interval__pb2.DESCRIPTOR,])



_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG = _descriptor.EnumDescriptor(
  name='PartOfSpeechTag',
  full_name='rst.dialog.SpeechHypothesis.Word.PartOfSpeechTag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADJA', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADV', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPR', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPRART', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPO', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APZR', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ART', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FM', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITJ', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORD', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOUI', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOUS', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KON', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOKOM', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NN', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NE', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PDS', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PDAT', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIS', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIAT', index=21, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIDAT', index=22, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPER', index=23, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPOSS', index=24, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPOSAT', index=25, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRELS', index=26, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRELAT', index=27, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRF', index=28, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWS', index=29, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWAT', index=30, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PWAV', index=31, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAV', index=32, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKZU', index=33, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKNEG', index=34, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKVZ', index=35, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKANT', index=36, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PTKA', index=37, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SGML', index=38, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPELL', index=39, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUNC', index=40, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVFIN', index=41, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVIMP', index=42, number=43,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVINF', index=43, number=44,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVIZU', index=44, number=45,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VVPP', index=45, number=46,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAFIN', index=46, number=47,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAIMP', index=47, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAINF', index=48, number=49,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAPP', index=49, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMFIN', index=50, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMINF', index=51, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VMPP', index=52, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XY', index=53, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KOMM', index=54, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END', index=55, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IPNCT', index=56, number=57,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=375,
  serialized_end=972,
)
_sym_db.RegisterEnumDescriptor(_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG)


_SPEECHHYPOTHESIS_WORD = _descriptor.Descriptor(
  name='Word',
  full_name='rst.dialog.SpeechHypothesis.Word',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word', full_name='rst.dialog.SpeechHypothesis.Word.word', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='rst.dialog.SpeechHypothesis.Word.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='part_of_speech_tag', full_name='rst.dialog.SpeechHypothesis.Word.part_of_speech_tag', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=972,
)

_SPEECHHYPOTHESIS = _descriptor.Descriptor(
  name='SpeechHypothesis',
  full_name='rst.dialog.SpeechHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='rst.dialog.SpeechHypothesis.words', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.dialog.SpeechHypothesis.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.dialog.SpeechHypothesis.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grammar_tree', full_name='rst.dialog.SpeechHypothesis.grammar_tree', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SPEECHHYPOTHESIS_WORD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=972,
)

_SPEECHHYPOTHESIS_WORD.fields_by_name['timestamps'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_SPEECHHYPOTHESIS_WORD.fields_by_name['part_of_speech_tag'].enum_type = _SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG
_SPEECHHYPOTHESIS_WORD.containing_type = _SPEECHHYPOTHESIS
_SPEECHHYPOTHESIS_WORD_PARTOFSPEECHTAG.containing_type = _SPEECHHYPOTHESIS_WORD
_SPEECHHYPOTHESIS.fields_by_name['words'].message_type = _SPEECHHYPOTHESIS_WORD
_SPEECHHYPOTHESIS.fields_by_name['timestamp'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
DESCRIPTOR.message_types_by_name['SpeechHypothesis'] = _SPEECHHYPOTHESIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechHypothesis = _reflection.GeneratedProtocolMessageType('SpeechHypothesis', (_message.Message,), dict(

  Word = _reflection.GeneratedProtocolMessageType('Word', (_message.Message,), dict(
    DESCRIPTOR = _SPEECHHYPOTHESIS_WORD,
    __module__ = 'rst.dialog.SpeechHypothesis_pb2'
    # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis.Word)
    ))
  ,
  DESCRIPTOR = _SPEECHHYPOTHESIS,
  __module__ = 'rst.dialog.SpeechHypothesis_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis)
  ))
_sym_db.RegisterMessage(SpeechHypothesis)
_sym_db.RegisterMessage(SpeechHypothesis.Word)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024SpeechHypothesisType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/SpeechHypotheses.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dialog import SpeechHypothesis_pb2 as rst_dot_dialog_dot_SpeechHypothesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/SpeechHypotheses.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n!rst/dialog/SpeechHypotheses.proto\x12\nrst.dialog\x1a!rst/dialog/SpeechHypothesis.proto\"\x8b\x01\n\x10SpeechHypotheses\x12\x31\n\x0b\x62\x65st_result\x18\x01 \x02(\x0b\x32\x1c.rst.dialog.SpeechHypothesis\x12\x35\n\x0f\x66urther_results\x18\x02 \x03(\x0b\x32\x1c.rst.dialog.SpeechHypothesis\x12\r\n\x05\x66inal\x18\x03 \x02(\x08\x42\x16\x42\x14SpeechHypothesesType')
  ,
  dependencies=[rst_dot_dialog_dot_SpeechHypothesis__pb2.DESCRIPTOR,])




_SPEECHHYPOTHESES = _descriptor.Descriptor(
  name='SpeechHypotheses',
  full_name='rst.dialog.SpeechHypotheses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='best_result', full_name='rst.dialog.SpeechHypotheses.best_result', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='further_results', full_name='rst.dialog.SpeechHypotheses.further_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='final', full_name='rst.dialog.SpeechHypotheses.final', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=224,
)

_SPEECHHYPOTHESES.fields_by_name['best_result'].message_type = rst_dot_dialog_dot_SpeechHypothesis__pb2._SPEECHHYPOTHESIS
_SPEECHHYPOTHESES.fields_by_name['further_results'].message_type = rst_dot_dialog_dot_SpeechHypothesis__pb2._SPEECHHYPOTHESIS
DESCRIPTOR.message_types_by_name['SpeechHypotheses'] = _SPEECHHYPOTHESES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechHypotheses = _reflection.GeneratedProtocolMessageType('SpeechHypotheses', (_message.Message,), dict(
  DESCRIPTOR = _SPEECHHYPOTHESES,
  __module__ = 'rst.dialog.SpeechHypotheses_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypotheses)
  ))
_sym_db.RegisterMessage(SpeechHypotheses)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024SpeechHypothesesType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Attendee.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Attendee.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/Attendee.proto\x12\x0crst.calendar\"\x9c\x05\n\x08\x41ttendee\x12\x17\n\x0f\x63\x61lendar_adress\x18\x01 \x02(\t\x12G\n\x12\x63\x61lendar_user_type\x18\x06 \x01(\x0e\x32\x1f.rst.calendar.Attendee.UserType:\nINDIVIDUAL\x12\x0e\n\x06member\x18\x07 \x03(\t\x12M\n\x12participation_role\x18\x08 \x01(\x0e\x32\x1b.rst.calendar.Attendee.Role:\x14REQUIRED_PARTICIPANT\x12V\n\x14participation_status\x18\t \x01(\x0e\x32*.rst.calendar.Attendee.ParticipationStatus:\x0cNEEDS_ACTION\x12\x1e\n\x0freply_requested\x18\n \x01(\x08:\x05\x66\x61lse\x12\x14\n\x0c\x64\x65legated_to\x18\x0b \x01(\t\x12\x16\n\x0e\x64\x65legated_from\x18\x0c \x01(\t\x12\x0f\n\x07sent_by\x18\x04 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x05 \x01(\t\"=\n\x08UserType\x12\x0e\n\nINDIVIDUAL\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\x0c\n\x08RESOURCE\x10\x03\x12\x08\n\x04ROOM\x10\x04\"Z\n\x04Role\x12\t\n\x05\x43HAIR\x10\x01\x12\x18\n\x14REQUIRED_PARTICIPANT\x10\x02\x12\x18\n\x14OPTIONAL_PARTICIPANT\x10\x03\x12\x13\n\x0fNON_PARTICIPANT\x10\x04\"C\n\x13ParticipationStatus\x12\x10\n\x0cNEEDS_ACTION\x10\x01\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x02\x12\x0c\n\x08\x44\x45\x43LINED\x10\x03\x42\x0e\x42\x0c\x41ttendeeType')
)



_ATTENDEE_USERTYPE = _descriptor.EnumDescriptor(
  name='UserType',
  full_name='rst.calendar.Attendee.UserType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDIVIDUAL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=492,
  serialized_end=553,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_USERTYPE)

_ATTENDEE_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='rst.calendar.Attendee.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHAIR', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUIRED_PARTICIPANT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIONAL_PARTICIPANT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NON_PARTICIPANT', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=555,
  serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_ROLE)

_ATTENDEE_PARTICIPATIONSTATUS = _descriptor.EnumDescriptor(
  name='ParticipationStatus',
  full_name='rst.calendar.Attendee.ParticipationStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEEDS_ACTION', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECLINED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=647,
  serialized_end=714,
)
_sym_db.RegisterEnumDescriptor(_ATTENDEE_PARTICIPATIONSTATUS)


_ATTENDEE = _descriptor.Descriptor(
  name='Attendee',
  full_name='rst.calendar.Attendee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_adress', full_name='rst.calendar.Attendee.calendar_adress', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calendar_user_type', full_name='rst.calendar.Attendee.calendar_user_type', index=1,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='rst.calendar.Attendee.member', index=2,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participation_role', full_name='rst.calendar.Attendee.participation_role', index=3,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participation_status', full_name='rst.calendar.Attendee.participation_status', index=4,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_requested', full_name='rst.calendar.Attendee.reply_requested', index=5,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delegated_to', full_name='rst.calendar.Attendee.delegated_to', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delegated_from', full_name='rst.calendar.Attendee.delegated_from', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_by', full_name='rst.calendar.Attendee.sent_by', index=8,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common_name', full_name='rst.calendar.Attendee.common_name', index=9,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='rst.calendar.Attendee.directory', index=10,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.Attendee.language', index=11,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ATTENDEE_USERTYPE,
    _ATTENDEE_ROLE,
    _ATTENDEE_PARTICIPATIONSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=714,
)

_ATTENDEE.fields_by_name['calendar_user_type'].enum_type = _ATTENDEE_USERTYPE
_ATTENDEE.fields_by_name['participation_role'].enum_type = _ATTENDEE_ROLE
_ATTENDEE.fields_by_name['participation_status'].enum_type = _ATTENDEE_PARTICIPATIONSTATUS
_ATTENDEE_USERTYPE.containing_type = _ATTENDEE
_ATTENDEE_ROLE.containing_type = _ATTENDEE
_ATTENDEE_PARTICIPATIONSTATUS.containing_type = _ATTENDEE
DESCRIPTOR.message_types_by_name['Attendee'] = _ATTENDEE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attendee = _reflection.GeneratedProtocolMessageType('Attendee', (_message.Message,), dict(
  DESCRIPTOR = _ATTENDEE,
  __module__ = 'rst.calendar.Attendee_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Attendee)
  ))
_sym_db.RegisterMessage(Attendee)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014AttendeeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Interval.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Timestamp_pb2 as rst_dot_timing_dot_Timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Interval.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\x19rst/timing/Interval.proto\x12\nrst.timing\x1a\x1arst/timing/Timestamp.proto\"T\n\x08Interval\x12$\n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x15.rst.timing.Timestamp\x12\"\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x15.rst.timing.TimestampB\x0e\x42\x0cIntervalType')
  ,
  dependencies=[rst_dot_timing_dot_Timestamp__pb2.DESCRIPTOR,])




_INTERVAL = _descriptor.Descriptor(
  name='Interval',
  full_name='rst.timing.Interval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='rst.timing.Interval.begin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='rst.timing.Interval.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=153,
)

_INTERVAL.fields_by_name['begin'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
_INTERVAL.fields_by_name['end'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Interval'] = _INTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interval = _reflection.GeneratedProtocolMessageType('Interval', (_message.Message,), dict(
  DESCRIPTOR = _INTERVAL,
  __module__ = 'rst.timing.Interval_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Interval)
  ))
_sym_db.RegisterMessage(Interval)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014IntervalType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/SimpleXYZImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/SimpleXYZImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/vision/SimpleXYZImage.proto\x12\nrst.vision\"P\n\x0eSimpleXYZImage\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\t\n\x01x\x18\x03 \x03(\x02\x12\t\n\x01y\x18\x04 \x03(\x02\x12\t\n\x01z\x18\x05 \x03(\x02\x42\x14\x42\x12SimpleXYZImageType')
)




_SIMPLEXYZIMAGE = _descriptor.Descriptor(
  name='SimpleXYZImage',
  full_name='rst.vision.SimpleXYZImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.SimpleXYZImage.width', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.SimpleXYZImage.height', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.vision.SimpleXYZImage.x', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.vision.SimpleXYZImage.y', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.vision.SimpleXYZImage.z', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=127,
)

DESCRIPTOR.message_types_by_name['SimpleXYZImage'] = _SIMPLEXYZIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleXYZImage = _reflection.GeneratedProtocolMessageType('SimpleXYZImage', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLEXYZIMAGE,
  __module__ = 'rst.vision.SimpleXYZImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.SimpleXYZImage)
  ))
_sym_db.RegisterMessage(SimpleXYZImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022SimpleXYZImageType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/JointTorquesCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.dynamics import JointTorques_pb2 as rst_dot_dynamics_dot_JointTorques__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/JointTorquesCollection.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n)rst/dynamics/JointTorquesCollection.proto\x12\x0crst.dynamics\x1a\x1frst/dynamics/JointTorques.proto\"E\n\x16JointTorquesCollection\x12+\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1a.rst.dynamics.JointTorquesB\x1c\x42\x1aJointTorquesCollectionType')
  ,
  dependencies=[rst_dot_dynamics_dot_JointTorques__pb2.DESCRIPTOR,])




_JOINTTORQUESCOLLECTION = _descriptor.Descriptor(
  name='JointTorquesCollection',
  full_name='rst.dynamics.JointTorquesCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.dynamics.JointTorquesCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=161,
)

_JOINTTORQUESCOLLECTION.fields_by_name['element'].message_type = rst_dot_dynamics_dot_JointTorques__pb2._JOINTTORQUES
DESCRIPTOR.message_types_by_name['JointTorquesCollection'] = _JOINTTORQUESCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JointTorquesCollection = _reflection.GeneratedProtocolMessageType('JointTorquesCollection', (_message.Message,), dict(
  DESCRIPTOR = _JOINTTORQUESCOLLECTION,
  __module__ = 'rst.dynamics.JointTorquesCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.JointTorquesCollection)
  ))
_sym_db.RegisterMessage(JointTorquesCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\032JointTorquesCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/BoundingBox3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/BoundingBox3DFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n%rst/geometry/BoundingBox3DFloat.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\"n\n\x12\x42oundingBox3DFloat\x12*\n\x0etransformation\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\r\n\x05width\x18\x02 \x02(\x02\x12\r\n\x05\x64\x65pth\x18\x03 \x02(\x02\x12\x0e\n\x06height\x18\x04 \x02(\x02\x42\x18\x42\x16\x42oundingBox3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_BOUNDINGBOX3DFLOAT = _descriptor.Descriptor(
  name='BoundingBox3DFloat',
  full_name='rst.geometry.BoundingBox3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation', full_name='rst.geometry.BoundingBox3DFloat.transformation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.BoundingBox3DFloat.width', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.geometry.BoundingBox3DFloat.depth', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.BoundingBox3DFloat.height', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=190,
)

_BOUNDINGBOX3DFLOAT.fields_by_name['transformation'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
DESCRIPTOR.message_types_by_name['BoundingBox3DFloat'] = _BOUNDINGBOX3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBox3DFloat = _reflection.GeneratedProtocolMessageType('BoundingBox3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOX3DFLOAT,
  __module__ = 'rst.geometry.BoundingBox3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.BoundingBox3DFloat)
  ))
_sym_db.RegisterMessage(BoundingBox3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026BoundingBox3DFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/CommandResult.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/CommandResult.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/navigation/CommandResult.proto\x12\x0erst.navigation\"\xf8\x01\n\rCommandResult\x12\x32\n\x04type\x18\x01 \x02(\x0e\x32$.rst.navigation.CommandResult.Result\x12\x0c\n\x04\x63ode\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x8f\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nSUPERSEDED\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x15\n\x11\x45MERGENCY_STOPPED\x10\x03\x12\x10\n\x0cPATH_BLOCKED\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x10\n\x0c\x43USTOM_ERROR\x10\x64\x12\x11\n\rUNKNOWN_ERROR\x10\x65\x42\x13\x42\x11\x43ommandResultType')
)



_COMMANDRESULT_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='rst.navigation.CommandResult.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERSEDED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_STOPPED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PATH_BLOCKED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_ERROR', index=6, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=7, number=101,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=160,
  serialized_end=303,
)
_sym_db.RegisterEnumDescriptor(_COMMANDRESULT_RESULT)


_COMMANDRESULT = _descriptor.Descriptor(
  name='CommandResult',
  full_name='rst.navigation.CommandResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.navigation.CommandResult.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='rst.navigation.CommandResult.code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='rst.navigation.CommandResult.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDRESULT_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=303,
)

_COMMANDRESULT.fields_by_name['type'].enum_type = _COMMANDRESULT_RESULT
_COMMANDRESULT_RESULT.containing_type = _COMMANDRESULT
DESCRIPTOR.message_types_by_name['CommandResult'] = _COMMANDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommandResult = _reflection.GeneratedProtocolMessageType('CommandResult', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESULT,
  __module__ = 'rst.navigation.CommandResult_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.CommandResult)
  ))
_sym_db.RegisterMessage(CommandResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021CommandResultType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResults.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.classification import ClassificationResult_pb2 as rst_dot_classification_dot_ClassificationResult__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResults.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n.rst/classification/ClassificationResults.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"R\n\x15\x43lassificationResults\x12\x39\n\x07\x63lasses\x18\x01 \x03(\x0b\x32(.rst.classification.ClassificationResultB\x1b\x42\x19\x43lassificationResultsType')
  ,
  dependencies=[rst_dot_classification_dot_ClassificationResult__pb2.DESCRIPTOR,])




_CLASSIFICATIONRESULTS = _descriptor.Descriptor(
  name='ClassificationResults',
  full_name='rst.classification.ClassificationResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResults.classes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=199,
)

_CLASSIFICATIONRESULTS.fields_by_name['classes'].message_type = rst_dot_classification_dot_ClassificationResult__pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassificationResults'] = _CLASSIFICATIONRESULTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResults = _reflection.GeneratedProtocolMessageType('ClassificationResults', (_message.Message,), dict(
  DESCRIPTOR = _CLASSIFICATIONRESULTS,
  __module__ = 'rst.classification.ClassificationResults_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResults)
  ))
_sym_db.RegisterMessage(ClassificationResults)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\031ClassificationResultsType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/ExecutionParameters.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/ExecutionParameters.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n(rst/navigation/ExecutionParameters.proto\x12\x0erst.navigation\"`\n\x13\x45xecutionParameters\x12\x0f\n\x07timeout\x18\x01 \x01(\x02\x12\x19\n\x11max_replan_cycles\x18\x64 \x01(\r\x12\x1d\n\x15use_fine_localization\x18\x65 \x01(\x08\x42\x19\x42\x17\x45xecutionParametersType')
)




_EXECUTIONPARAMETERS = _descriptor.Descriptor(
  name='ExecutionParameters',
  full_name='rst.navigation.ExecutionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='rst.navigation.ExecutionParameters.timeout', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_replan_cycles', full_name='rst.navigation.ExecutionParameters.max_replan_cycles', index=1,
      number=100, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_fine_localization', full_name='rst.navigation.ExecutionParameters.use_fine_localization', index=2,
      number=101, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=156,
)

DESCRIPTOR.message_types_by_name['ExecutionParameters'] = _EXECUTIONPARAMETERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecutionParameters = _reflection.GeneratedProtocolMessageType('ExecutionParameters', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONPARAMETERS,
  __module__ = 'rst.navigation.ExecutionParameters_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.ExecutionParameters)
  ))
_sym_db.RegisterMessage(ExecutionParameters)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027ExecutionParametersType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/LaserScan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/LaserScan.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/vision/LaserScan.proto\x12\nrst.vision\"4\n\tLaserScan\x12\x13\n\x0bscan_values\x18\x01 \x03(\x02\x12\x12\n\nscan_angle\x18\x02 \x02(\x02\x42\x0f\x42\rLaserScanType')
)




_LASERSCAN = _descriptor.Descriptor(
  name='LaserScan',
  full_name='rst.vision.LaserScan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_values', full_name='rst.vision.LaserScan.scan_values', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_angle', full_name='rst.vision.LaserScan.scan_angle', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=94,
)

DESCRIPTOR.message_types_by_name['LaserScan'] = _LASERSCAN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaserScan = _reflection.GeneratedProtocolMessageType('LaserScan', (_message.Message,), dict(
  DESCRIPTOR = _LASERSCAN,
  __module__ = 'rst.vision.LaserScan_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.LaserScan)
  ))
_sym_db.RegisterMessage(LaserScan)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rLaserScanType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/MemoryState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/MemoryState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n%rst/devices/generic/MemoryState.proto\x12\x13rst.devices.generic\"a\n\x0bMemoryState\x12\r\n\x05total\x18\x02 \x01(\x02\x12\x0c\n\x04used\x18\x03 \x01(\x02\x12\x0e\n\x06usable\x18\x04 \x01(\x04\x12\x12\n\nswap_total\x18\x05 \x01(\x04\x12\x11\n\tswap_used\x18\x06 \x01(\x04\x42\x11\x42\x0fMemoryStateType')
)




_MEMORYSTATE = _descriptor.Descriptor(
  name='MemoryState',
  full_name='rst.devices.generic.MemoryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='rst.devices.generic.MemoryState.total', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='used', full_name='rst.devices.generic.MemoryState.used', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='usable', full_name='rst.devices.generic.MemoryState.usable', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap_total', full_name='rst.devices.generic.MemoryState.swap_total', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swap_used', full_name='rst.devices.generic.MemoryState.swap_used', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=159,
)

DESCRIPTOR.message_types_by_name['MemoryState'] = _MEMORYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MemoryState = _reflection.GeneratedProtocolMessageType('MemoryState', (_message.Message,), dict(
  DESCRIPTOR = _MEMORYSTATE,
  __module__ = 'rst.devices.generic.MemoryState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.MemoryState)
  ))
_sym_db.RegisterMessage(MemoryState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017MemoryStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/BoundingBoxCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import BoundingBox_pb2 as rst_dot_geometry_dot_BoundingBox__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/BoundingBoxCollection.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n(rst/geometry/BoundingBoxCollection.proto\x12\x0crst.geometry\x1a\x1erst/geometry/BoundingBox.proto\"C\n\x15\x42oundingBoxCollection\x12*\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x19.rst.geometry.BoundingBoxB\x1b\x42\x19\x42oundingBoxCollectionType')
  ,
  dependencies=[rst_dot_geometry_dot_BoundingBox__pb2.DESCRIPTOR,])




_BOUNDINGBOXCOLLECTION = _descriptor.Descriptor(
  name='BoundingBoxCollection',
  full_name='rst.geometry.BoundingBoxCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.BoundingBoxCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=157,
)

_BOUNDINGBOXCOLLECTION.fields_by_name['element'].message_type = rst_dot_geometry_dot_BoundingBox__pb2._BOUNDINGBOX
DESCRIPTOR.message_types_by_name['BoundingBoxCollection'] = _BOUNDINGBOXCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundingBoxCollection = _reflection.GeneratedProtocolMessageType('BoundingBoxCollection', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOXCOLLECTION,
  __module__ = 'rst.geometry.BoundingBoxCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.BoundingBoxCollection)
  ))
_sym_db.RegisterMessage(BoundingBoxCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\031BoundingBoxCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/State.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/State.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n\x18rst/tracking/State.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\"\xe8\x02\n\x05State\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12.\n\x06\x61spect\x18\x02 \x03(\x0e\x32\x1a.rst.tracking.State.AspectB\x02\x10\x01\"\x84\x02\n\x06\x41spect\x12\x16\n\x12\x41SPECT_POSITION_2D\x10\x00\x12\x16\n\x12\x41SPECT_POSITION_3D\x10\x01\x12\'\n#ASPECT_AXIS_ALIGNED_BOUNDING_BOX_2D\x10\x02\x12\'\n#ASPECT_AXIS_ALIGNED_BOUNDING_BOX_3D\x10\x03\x12\x1a\n\x16\x41SPECT_BOUNDING_BOX_2D\x10\x04\x12\x1a\n\x16\x41SPECT_BOUNDING_BOX_3D\x10\x05\x12\x12\n\x0e\x41SPECT_CONTOUR\x10\x06\x12\x15\n\x11\x41SPECT_POSTURE_2D\x10\x07\x12\x15\n\x11\x41SPECT_POSTURE_3D\x10\x08\x42\x0b\x42\tStateType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,])



_STATE_ASPECT = _descriptor.EnumDescriptor(
  name='Aspect',
  full_name='rst.tracking.State.Aspect',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASPECT_POSITION_2D', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_POSITION_3D', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_AXIS_ALIGNED_BOUNDING_BOX_2D', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_AXIS_ALIGNED_BOUNDING_BOX_3D', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_BOUNDING_BOX_2D', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_BOUNDING_BOX_3D', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_CONTOUR', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_POSTURE_2D', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_POSTURE_3D', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=176,
  serialized_end=436,
)
_sym_db.RegisterEnumDescriptor(_STATE_ASPECT)


_STATE = _descriptor.Descriptor(
  name='State',
  full_name='rst.tracking.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.State.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aspect', full_name='rst.tracking.State.aspect', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATE_ASPECT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=436,
)

_STATE.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_STATE.fields_by_name['aspect'].enum_type = _STATE_ASPECT
_STATE_ASPECT.containing_type = _STATE
DESCRIPTOR.message_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), dict(
  DESCRIPTOR = _STATE,
  __module__ = 'rst.tracking.State_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.State)
  ))
_sym_db.RegisterMessage(State)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tStateType'))
_STATE.fields_by_name['aspect'].has_options = True
_STATE.fields_by_name['aspect']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/rfid/Tag.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/rfid/Tag.proto',
  package='rst.devices.rfid',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/devices/rfid/Tag.proto\x12\x10rst.devices.rfid\"1\n\x03Tag\x12\n\n\x02id\x18\x01 \x02(\x0c\x12\x0e\n\x06vendor\x18\x02 \x01(\x0c\x12\x0e\n\x06source\x18\x03 \x01(\x0c\x42\tB\x07TagType')
)




_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='rst.devices.rfid.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.devices.rfid.Tag.id', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='rst.devices.rfid.Tag.vendor', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='rst.devices.rfid.Tag.source', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Tag'] = _TAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
  DESCRIPTOR = _TAG,
  __module__ = 'rst.devices.rfid.Tag_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.rfid.Tag)
  ))
_sym_db.RegisterMessage(Tag)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\007TagType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/BodyList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.hri import Body_pb2 as rst_dot_hri_dot_Body__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/BodyList.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/hri/BodyList.proto\x12\x07rst.hri\x1a\x12rst/hri/Body.proto\"*\n\x08\x42odyList\x12\x1e\n\x07\x65lement\x18\x01 \x03(\x0b\x32\r.rst.hri.BodyB\x0e\x42\x0c\x42odyListType')
  ,
  dependencies=[rst_dot_hri_dot_Body__pb2.DESCRIPTOR,])




_BODYLIST = _descriptor.Descriptor(
  name='BodyList',
  full_name='rst.hri.BodyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.hri.BodyList.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=97,
)

_BODYLIST.fields_by_name['element'].message_type = rst_dot_hri_dot_Body__pb2._BODY
DESCRIPTOR.message_types_by_name['BodyList'] = _BODYLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BodyList = _reflection.GeneratedProtocolMessageType('BodyList', (_message.Message,), dict(
  DESCRIPTOR = _BODYLIST,
  __module__ = 'rst.hri.BodyList_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.BodyList)
  ))
_sym_db.RegisterMessage(BodyList)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014BodyListType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/EmotionExpression.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/EmotionExpression.proto',
  package='rst.animation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/animation/EmotionExpression.proto\x12\rrst.animation\"\xb0\x01\n\x11\x45motionExpression\x12\x39\n\x07\x65motion\x18\x01 \x02(\x0e\x32(.rst.animation.EmotionExpression.Emotion\x12\x10\n\x08\x64uration\x18\x02 \x02(\r\"N\n\x07\x45motion\x12\x0b\n\x07NEUTRAL\x10\x00\x12\t\n\x05HAPPY\x10\x01\x12\x07\n\x03SAD\x10\x02\x12\t\n\x05\x41NGRY\x10\x03\x12\r\n\tSURPRISED\x10\x04\x12\x08\n\x04\x46\x45\x41R\x10\x05\x42\x17\x42\x15\x45motionExpressionType')
)



_EMOTIONEXPRESSION_EMOTION = _descriptor.EnumDescriptor(
  name='Emotion',
  full_name='rst.animation.EmotionExpression.Emotion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEUTRAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAPPY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANGRY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SURPRISED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEAR', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=155,
  serialized_end=233,
)
_sym_db.RegisterEnumDescriptor(_EMOTIONEXPRESSION_EMOTION)


_EMOTIONEXPRESSION = _descriptor.Descriptor(
  name='EmotionExpression',
  full_name='rst.animation.EmotionExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emotion', full_name='rst.animation.EmotionExpression.emotion', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.animation.EmotionExpression.duration', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EMOTIONEXPRESSION_EMOTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=233,
)

_EMOTIONEXPRESSION.fields_by_name['emotion'].enum_type = _EMOTIONEXPRESSION_EMOTION
_EMOTIONEXPRESSION_EMOTION.containing_type = _EMOTIONEXPRESSION
DESCRIPTOR.message_types_by_name['EmotionExpression'] = _EMOTIONEXPRESSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmotionExpression = _reflection.GeneratedProtocolMessageType('EmotionExpression', (_message.Message,), dict(
  DESCRIPTOR = _EMOTIONEXPRESSION,
  __module__ = 'rst.animation.EmotionExpression_pb2'
  # @@protoc_insertion_point(class_scope:rst.animation.EmotionExpression)
  ))
_sym_db.RegisterMessage(EmotionExpression)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025EmotionExpressionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tts/TextToSpeechInstruction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tts import Prosody_pb2 as rst_dot_tts_dot_Prosody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tts/TextToSpeechInstruction.proto',
  package='rst.tts',
  syntax='proto2',
  serialized_pb=_b('\n%rst/tts/TextToSpeechInstruction.proto\x12\x07rst.tts\x1a\x15rst/tts/Prosody.proto\"\xd7\x01\n\x17TextToSpeechInstruction\x12\x0c\n\x04text\x18\x01 \x01(\t\x12!\n\x07prosody\x18\x02 \x01(\x0b\x32\x10.rst.tts.Prosody\x12N\n\x0fplayback_option\x18\x03 \x01(\x0e\x32/.rst.tts.TextToSpeechInstruction.PlaybackOption:\x04PLAY\";\n\x0ePlaybackOption\x12\x08\n\x04PLAY\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x42\x1d\x42\x1bTextToSpeechInstructionType')
  ,
  dependencies=[rst_dot_tts_dot_Prosody__pb2.DESCRIPTOR,])



_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION = _descriptor.EnumDescriptor(
  name='PlaybackOption',
  full_name='rst.tts.TextToSpeechInstruction.PlaybackOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLAY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=230,
  serialized_end=289,
)
_sym_db.RegisterEnumDescriptor(_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION)


_TEXTTOSPEECHINSTRUCTION = _descriptor.Descriptor(
  name='TextToSpeechInstruction',
  full_name='rst.tts.TextToSpeechInstruction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='rst.tts.TextToSpeechInstruction.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prosody', full_name='rst.tts.TextToSpeechInstruction.prosody', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playback_option', full_name='rst.tts.TextToSpeechInstruction.playback_option', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=289,
)

_TEXTTOSPEECHINSTRUCTION.fields_by_name['prosody'].message_type = rst_dot_tts_dot_Prosody__pb2._PROSODY
_TEXTTOSPEECHINSTRUCTION.fields_by_name['playback_option'].enum_type = _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION
_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION.containing_type = _TEXTTOSPEECHINSTRUCTION
DESCRIPTOR.message_types_by_name['TextToSpeechInstruction'] = _TEXTTOSPEECHINSTRUCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextToSpeechInstruction = _reflection.GeneratedProtocolMessageType('TextToSpeechInstruction', (_message.Message,), dict(
  DESCRIPTOR = _TEXTTOSPEECHINSTRUCTION,
  __module__ = 'rst.tts.TextToSpeechInstruction_pb2'
  # @@protoc_insertion_point(class_scope:rst.tts.TextToSpeechInstruction)
  ))
_sym_db.RegisterMessage(TextToSpeechInstruction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033TextToSpeechInstructionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/scene/SceneObjectQuery.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/scene/SceneObjectQuery.proto',
  package='rst.scene',
  syntax='proto2',
  serialized_pb=_b('\n rst/scene/SceneObjectQuery.proto\x12\trst.scene\"D\n\x10SceneObjectQuery\x12\x17\n\x0bname_filter\x18\x01 \x01(\t:\x02.*\x12\x17\n\x0bkind_filter\x18\x02 \x01(\t:\x02.*B\x16\x42\x14SceneObjectQueryType')
)




_SCENEOBJECTQUERY = _descriptor.Descriptor(
  name='SceneObjectQuery',
  full_name='rst.scene.SceneObjectQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_filter', full_name='rst.scene.SceneObjectQuery.name_filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b(".*").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kind_filter', full_name='rst.scene.SceneObjectQuery.kind_filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b(".*").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=115,
)

DESCRIPTOR.message_types_by_name['SceneObjectQuery'] = _SCENEOBJECTQUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SceneObjectQuery = _reflection.GeneratedProtocolMessageType('SceneObjectQuery', (_message.Message,), dict(
  DESCRIPTOR = _SCENEOBJECTQUERY,
  __module__ = 'rst.scene.SceneObjectQuery_pb2'
  # @@protoc_insertion_point(class_scope:rst.scene.SceneObjectQuery)
  ))
_sym_db.RegisterMessage(SceneObjectQuery)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024SceneObjectQueryType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/CoordinateCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.navigation import ExecutionParameters_pb2 as rst_dot_navigation_dot_ExecutionParameters__pb2
from rst.navigation import MotionParameters_pb2 as rst_dot_navigation_dot_MotionParameters__pb2
from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/CoordinateCommand.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n&rst/navigation/CoordinateCommand.proto\x12\x0erst.navigation\x1a(rst/navigation/ExecutionParameters.proto\x1a%rst/navigation/MotionParameters.proto\x1a\x17rst/geometry/Pose.proto\"\xb5\x01\n\x11\x43oordinateCommand\x12 \n\x04goal\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12;\n\x11motion_parameters\x18\x02 \x01(\x0b\x32 .rst.navigation.MotionParameters\x12\x41\n\x14\x65xecution_parameters\x18\x03 \x01(\x0b\x32#.rst.navigation.ExecutionParametersB\x17\x42\x15\x43oordinateCommandType')
  ,
  dependencies=[rst_dot_navigation_dot_ExecutionParameters__pb2.DESCRIPTOR,rst_dot_navigation_dot_MotionParameters__pb2.DESCRIPTOR,rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_COORDINATECOMMAND = _descriptor.Descriptor(
  name='CoordinateCommand',
  full_name='rst.navigation.CoordinateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='rst.navigation.CoordinateCommand.goal', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_parameters', full_name='rst.navigation.CoordinateCommand.motion_parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='execution_parameters', full_name='rst.navigation.CoordinateCommand.execution_parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=346,
)

_COORDINATECOMMAND.fields_by_name['goal'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_COORDINATECOMMAND.fields_by_name['motion_parameters'].message_type = rst_dot_navigation_dot_MotionParameters__pb2._MOTIONPARAMETERS
_COORDINATECOMMAND.fields_by_name['execution_parameters'].message_type = rst_dot_navigation_dot_ExecutionParameters__pb2._EXECUTIONPARAMETERS
DESCRIPTOR.message_types_by_name['CoordinateCommand'] = _COORDINATECOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CoordinateCommand = _reflection.GeneratedProtocolMessageType('CoordinateCommand', (_message.Message,), dict(
  DESCRIPTOR = _COORDINATECOMMAND,
  __module__ = 'rst.navigation.CoordinateCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.CoordinateCommand)
  ))
_sym_db.RegisterMessage(CoordinateCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025CoordinateCommandType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Shape3DFloatCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Shape3DFloat_pb2 as rst_dot_geometry_dot_Shape3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Shape3DFloatCollection.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n)rst/geometry/Shape3DFloatCollection.proto\x12\x0crst.geometry\x1a\x1frst/geometry/Shape3DFloat.proto\"E\n\x16Shape3DFloatCollection\x12+\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1a.rst.geometry.Shape3DFloatB\x1c\x42\x1aShape3DFloatCollectionType')
  ,
  dependencies=[rst_dot_geometry_dot_Shape3DFloat__pb2.DESCRIPTOR,])




_SHAPE3DFLOATCOLLECTION = _descriptor.Descriptor(
  name='Shape3DFloatCollection',
  full_name='rst.geometry.Shape3DFloatCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.Shape3DFloatCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=161,
)

_SHAPE3DFLOATCOLLECTION.fields_by_name['element'].message_type = rst_dot_geometry_dot_Shape3DFloat__pb2._SHAPE3DFLOAT
DESCRIPTOR.message_types_by_name['Shape3DFloatCollection'] = _SHAPE3DFLOATCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Shape3DFloatCollection = _reflection.GeneratedProtocolMessageType('Shape3DFloatCollection', (_message.Message,), dict(
  DESCRIPTOR = _SHAPE3DFLOATCOLLECTION,
  __module__ = 'rst.geometry.Shape3DFloatCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.Shape3DFloatCollection)
  ))
_sym_db.RegisterMessage(Shape3DFloatCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\032Shape3DFloatCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/RobotCollision.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.kinematics import ObjectCollision_pb2 as rst_dot_kinematics_dot_ObjectCollision__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/RobotCollision.proto',
  package='rst.robot',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/robot/RobotCollision.proto\x12\trst.robot\x1a$rst/kinematics/ObjectCollision.proto\"\xb8\x01\n\x0eRobotCollision\x12\x35\n\x04kind\x18\x01 \x02(\x0e\x32\'.rst.robot.RobotCollision.CollisionKind\x12\x39\n\x10\x63ollision_detail\x18\x02 \x02(\x0b\x32\x1f.rst.kinematics.ObjectCollision\"4\n\rCollisionKind\x12\x08\n\x04SELF\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03\x42\x14\x42\x12RobotCollisionType')
  ,
  dependencies=[rst_dot_kinematics_dot_ObjectCollision__pb2.DESCRIPTOR,])



_ROBOTCOLLISION_COLLISIONKIND = _descriptor.EnumDescriptor(
  name='CollisionKind',
  full_name='rst.robot.RobotCollision.CollisionKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SELF', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=216,
  serialized_end=268,
)
_sym_db.RegisterEnumDescriptor(_ROBOTCOLLISION_COLLISIONKIND)


_ROBOTCOLLISION = _descriptor.Descriptor(
  name='RobotCollision',
  full_name='rst.robot.RobotCollision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='rst.robot.RobotCollision.kind', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='collision_detail', full_name='rst.robot.RobotCollision.collision_detail', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROBOTCOLLISION_COLLISIONKIND,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=268,
)

_ROBOTCOLLISION.fields_by_name['kind'].enum_type = _ROBOTCOLLISION_COLLISIONKIND
_ROBOTCOLLISION.fields_by_name['collision_detail'].message_type = rst_dot_kinematics_dot_ObjectCollision__pb2._OBJECTCOLLISION
_ROBOTCOLLISION_COLLISIONKIND.containing_type = _ROBOTCOLLISION
DESCRIPTOR.message_types_by_name['RobotCollision'] = _ROBOTCOLLISION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotCollision = _reflection.GeneratedProtocolMessageType('RobotCollision', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTCOLLISION,
  __module__ = 'rst.robot.RobotCollision_pb2'
  # @@protoc_insertion_point(class_scope:rst.robot.RobotCollision)
  ))
_sym_db.RegisterMessage(RobotCollision)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022RobotCollisionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/TimeZone.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Observance_pb2 as rst_dot_calendar_dot_Observance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/TimeZone.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/calendar/TimeZone.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x1drst/calendar/Observance.proto\"\xd6\x01\n\x08TimeZone\x12\x13\n\x0btimezone_id\x18\x01 \x02(\t\x12\x31\n\x11last_modified_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x14\n\x0ctimezone_url\x18\x03 \x01(\t\x12\x12\n\nx_location\x18\x04 \x01(\t\x12+\n\tstandards\x18\x05 \x03(\x0b\x32\x18.rst.calendar.Observance\x12+\n\tdaylights\x18\x06 \x03(\x0b\x32\x18.rst.calendar.ObservanceB\x0e\x42\x0cTimeZoneType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Observance__pb2.DESCRIPTOR,])




_TIMEZONE = _descriptor.Descriptor(
  name='TimeZone',
  full_name='rst.calendar.TimeZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezone_id', full_name='rst.calendar.TimeZone.timezone_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified_utc', full_name='rst.calendar.TimeZone.last_modified_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timezone_url', full_name='rst.calendar.TimeZone.timezone_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x_location', full_name='rst.calendar.TimeZone.x_location', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standards', full_name='rst.calendar.TimeZone.standards', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='daylights', full_name='rst.calendar.TimeZone.daylights', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=320,
)

_TIMEZONE.fields_by_name['last_modified_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_TIMEZONE.fields_by_name['standards'].message_type = rst_dot_calendar_dot_Observance__pb2._OBSERVANCE
_TIMEZONE.fields_by_name['daylights'].message_type = rst_dot_calendar_dot_Observance__pb2._OBSERVANCE
DESCRIPTOR.message_types_by_name['TimeZone'] = _TIMEZONE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeZone = _reflection.GeneratedProtocolMessageType('TimeZone', (_message.Message,), dict(
  DESCRIPTOR = _TIMEZONE,
  __module__ = 'rst.calendar.TimeZone_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.TimeZone)
  ))
_sym_db.RegisterMessage(TimeZone)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014TimeZoneType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/OccupancyGrid2DInt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/OccupancyGrid2DInt.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n\'rst/navigation/OccupancyGrid2DInt.proto\x12\x0erst.navigation\x1a\x17rst/geometry/Pose.proto\"x\n\x12OccupancyGrid2DInt\x12\x12\n\nresolution\x18\x01 \x02(\x02\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\"\n\x06origin\x18\x04 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x0b\n\x03map\x18\x05 \x02(\x0c\x42\x18\x42\x16OccupancyGrid2DIntType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_OCCUPANCYGRID2DINT = _descriptor.Descriptor(
  name='OccupancyGrid2DInt',
  full_name='rst.navigation.OccupancyGrid2DInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='rst.navigation.OccupancyGrid2DInt.resolution', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.navigation.OccupancyGrid2DInt.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.navigation.OccupancyGrid2DInt.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='rst.navigation.OccupancyGrid2DInt.origin', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map', full_name='rst.navigation.OccupancyGrid2DInt.map', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=204,
)

_OCCUPANCYGRID2DINT.fields_by_name['origin'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
DESCRIPTOR.message_types_by_name['OccupancyGrid2DInt'] = _OCCUPANCYGRID2DINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OccupancyGrid2DInt = _reflection.GeneratedProtocolMessageType('OccupancyGrid2DInt', (_message.Message,), dict(
  DESCRIPTOR = _OCCUPANCYGRID2DINT,
  __module__ = 'rst.navigation.OccupancyGrid2DInt_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.OccupancyGrid2DInt)
  ))
_sym_db.RegisterMessage(OccupancyGrid2DInt)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026OccupancyGrid2DIntType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/IncrementalUnit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Interval_pb2 as rst_dot_timing_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/IncrementalUnit.proto',
  package='rst.dialog',
  syntax='proto2',
  serialized_pb=_b('\n rst/dialog/IncrementalUnit.proto\x12\nrst.dialog\x1a\x19rst/timing/Interval.proto\"\xd6\x01\n\x0fIncrementalUnit\x12(\n\ntimestamps\x18\x02 \x01(\x0b\x32\x14.rst.timing.Interval\x12\n\n\x02id\x18\x03 \x02(\x0c\x12\x0e\n\x06sll_id\x18\x04 \x03(\x0c\x12\x0e\n\x06gil_id\x18\x05 \x03(\x0c\x12\x33\n\x05state\x18\x06 \x02(\x0e\x32$.rst.dialog.IncrementalUnit.EditType\"8\n\x08\x45\x64itType\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\x0b\n\x07UPDATED\x10\x01\x12\n\n\x06REVOKE\x10\x02\x12\n\n\x06\x43OMMIT\x10\x03\x42\x15\x42\x13IncrementalUnitType')
  ,
  dependencies=[rst_dot_timing_dot_Interval__pb2.DESCRIPTOR,])



_INCREMENTALUNIT_EDITTYPE = _descriptor.EnumDescriptor(
  name='EditType',
  full_name='rst.dialog.IncrementalUnit.EditType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVOKE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMIT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=234,
  serialized_end=290,
)
_sym_db.RegisterEnumDescriptor(_INCREMENTALUNIT_EDITTYPE)


_INCREMENTALUNIT = _descriptor.Descriptor(
  name='IncrementalUnit',
  full_name='rst.dialog.IncrementalUnit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='rst.dialog.IncrementalUnit.timestamps', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.dialog.IncrementalUnit.id', index=1,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sll_id', full_name='rst.dialog.IncrementalUnit.sll_id', index=2,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gil_id', full_name='rst.dialog.IncrementalUnit.gil_id', index=3,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.dialog.IncrementalUnit.state', index=4,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INCREMENTALUNIT_EDITTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=290,
)

_INCREMENTALUNIT.fields_by_name['timestamps'].message_type = rst_dot_timing_dot_Interval__pb2._INTERVAL
_INCREMENTALUNIT.fields_by_name['state'].enum_type = _INCREMENTALUNIT_EDITTYPE
_INCREMENTALUNIT_EDITTYPE.containing_type = _INCREMENTALUNIT
DESCRIPTOR.message_types_by_name['IncrementalUnit'] = _INCREMENTALUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IncrementalUnit = _reflection.GeneratedProtocolMessageType('IncrementalUnit', (_message.Message,), dict(
  DESCRIPTOR = _INCREMENTALUNIT,
  __module__ = 'rst.dialog.IncrementalUnit_pb2'
  # @@protoc_insertion_point(class_scope:rst.dialog.IncrementalUnit)
  ))
_sym_db.RegisterMessage(IncrementalUnit)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023IncrementalUnitType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/MixtureOfGaussian1D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.stochastics import Gaussian1D_pb2 as rst_dot_stochastics_dot_Gaussian1D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/MixtureOfGaussian1D.proto',
  package='rst.stochastics',
  syntax='proto2',
  serialized_pb=_b('\n)rst/stochastics/MixtureOfGaussian1D.proto\x12\x0frst.stochastics\x1a rst/stochastics/Gaussian1D.proto\"\xd4\x01\n\x13MixtureOfGaussian1D\x12L\n\ncomponents\x18\x01 \x03(\x0b\x32\x38.rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D\x1ao\n\x13GaussianComponent1D\x12-\n\x08gaussian\x18\x01 \x02(\x0b\x32\x1b.rst.stochastics.Gaussian1D\x12\x0e\n\x06weight\x18\x02 \x02(\x02\x12\x19\n\x11probability_state\x18\x03 \x02(\x02\x42\x19\x42\x17MixtureOfGaussian1DType')
  ,
  dependencies=[rst_dot_stochastics_dot_Gaussian1D__pb2.DESCRIPTOR,])




_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D = _descriptor.Descriptor(
  name='GaussianComponent1D',
  full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaussian', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.gaussian', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.weight', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability_state', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.probability_state', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D = _descriptor.Descriptor(
  name='MixtureOfGaussian1D',
  full_name='rst.stochastics.MixtureOfGaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='rst.stochastics.MixtureOfGaussian1D.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.fields_by_name['gaussian'].message_type = rst_dot_stochastics_dot_Gaussian1D__pb2._GAUSSIAN1D
_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.containing_type = _MIXTUREOFGAUSSIAN1D
_MIXTUREOFGAUSSIAN1D.fields_by_name['components'].message_type = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D
DESCRIPTOR.message_types_by_name['MixtureOfGaussian1D'] = _MIXTUREOFGAUSSIAN1D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MixtureOfGaussian1D = _reflection.GeneratedProtocolMessageType('MixtureOfGaussian1D', (_message.Message,), dict(

  GaussianComponent1D = _reflection.GeneratedProtocolMessageType('GaussianComponent1D', (_message.Message,), dict(
    DESCRIPTOR = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D,
    __module__ = 'rst.stochastics.MixtureOfGaussian1D_pb2'
    # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D)
    ))
  ,
  DESCRIPTOR = _MIXTUREOFGAUSSIAN1D,
  __module__ = 'rst.stochastics.MixtureOfGaussian1D_pb2'
  # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D)
  ))
_sym_db.RegisterMessage(MixtureOfGaussian1D)
_sym_db.RegisterMessage(MixtureOfGaussian1D.GaussianComponent1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\027MixtureOfGaussian1DType'))
# @@protoc_insertion_point(module_scope)
